using System;

namespace MonoDevelop.WebReferences
{
	/// <summary>Defines an enumeration of all the available commands for maintaining Web References.</summary>
	public enum WebReferenceCommands
	{
		Add,
		Update,
		UpdateAll,
		Delete,
		DeleteAll,
		Configure
	}
}
